Set parameters controlling Cox model estimation of mediation effects
Source:R/params.R
params_med_cox.RdThis should be used in conjunction with est_med to
set parameters controlling Cox model estimation of mediation effects;
see examples.
Examples
data(hvtn505)
dat <- load_data(time="HIVwk28preunblfu", event="HIVwk28preunbl", vacc="trt",
marker="IgG_V2", covariates=c("age","BMI","bhvrisk"),
weights="wt", ph2="casecontrol", data=hvtn505)
# \donttest{
ests_med <- est_med(
dat = dat,
type = "Cox",
t_0 = 578,
params_np = params_med_cox(edge_ind=TRUE)
)
# }